@@ -5,15 +5,15 @@ use warnings;
 use bytes;
 require Exporter ;
 
-use IO::Compress::Base 2.201 ;
-use IO::Compress::Base::Common  2.201 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Xz 2.201 ;
-use Compress::Raw::Lzma  2.201 ;
+use IO::Compress::Base 2.205 ;
+use IO::Compress::Base::Common  2.205 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Xz 2.205 ;
+use Compress::Raw::Lzma  2.205 ;
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $XzError);
 
-$VERSION = '2.201';
+$VERSION = '2.205';
 $XzError = '';
 
 @ISA    = qw(IO::Compress::Base Exporter);
@@ -371,7 +371,7 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
+=head2 Oneshot Examples
 
 Here are a few example that show the capabilities of the module.
 
@@ -450,7 +450,10 @@ The format of the constructor for C<IO::Compress::Xz> is shown below
     my $z = IO::Compress::Xz->new( $output [,OPTS] )
         or die "IO::Compress::Xz failed: $XzError\n";
 
-It returns an C<IO::Compress::Xz> object on success and undef on failure.
+The constructor takes one mandatory parameter, C<$output>, defined below and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
+It returns an C<IO::Compress::Xz> object on success and C<undef> on failure.
 The variable C<$XzError> will contain an error message on failure.
 
 If you are running Perl 5.005 or better the object, C<$z>, returned from
@@ -463,6 +466,18 @@ these forms
     $z->print("hello world\n");
     print $z "hello world\n";
 
+Below is a simple exaple of using the OO interface to create an output file
+C<myfile.xz> and write some data to it.
+
+    my $filename = "myfile.xz";
+    my $z = IO::Compress::Xz->new($filename)
+        or die "IO::Compress::Xz failed: $XzError\n";
+
+    $z->print("abcde");
+    $z->close();
+
+See the L</Examples> for more.
+
 The mandatory parameter C<$output> is used to control the destination
 of the compressed data. This parameter can take one of these forms.
 
@@ -571,7 +586,52 @@ This is a placeholder option.
 
 =head2 Examples
 
-TODO
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities
+of the module. The code reads data from STDIN or all the files given on the
+commandline, compresses it, and writes the compressed data to STDOUT.
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Xz qw(xz $XzError) ;
+
+    my $z = IO::Compress::Xz->new("-", Stream => 1)
+        or die "IO::Compress::Xz failed: $XzError\n";
+
+    while (<>) {
+        $z->print("abcde");
+    }
+    $z->close();
+
+Note the use of C<"-"> to means C<STDOUT>. Alternatively you can use C<\*STDOUT>.
+
+=head3 Compressing a file from the filesystem
+
+To read the contents of the file C<file1.txt> and write the compressed
+data to the file C<file1.txt.xz> there are a few options
+
+Start by creating the compression object and opening the input file
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Xz qw(xz $XzError) ;
+
+    my $input = "file1.txt";
+    my $z = IO::Compress::Xz->new("file1.txt.xz")
+        or die "IO::Compress::Xz failed: $XzError\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # not forgetting to close the compressed file
+    $z->close();
 
 =head1 Methods
 
@@ -799,7 +859,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
