@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.201 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.205 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.201 ;
-use IO::Uncompress::Adapter::UnLzip 2.201 ;
+use IO::Uncompress::Base 2.205 ;
+use IO::Uncompress::Adapter::UnLzip 2.205 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzipError);
 
-$VERSION = '2.201';
+$VERSION = '2.205';
 $UnLzipError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
@@ -472,7 +472,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.xz> and write the
 uncompressed data to the file C<file1.txt>.
@@ -532,6 +532,9 @@ The format of the constructor for IO::Uncompress::UnLzip is shown below
     my $z = IO::Uncompress::UnLzip->new( $input [OPTS] )
         or die "IO::Uncompress::UnLzip failed: $UnLzipError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::UnLzip> object on success and undef on failure.
 The variable C<$UnLzipError> will contain an error message on failure.
 
@@ -544,6 +547,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.xz> and write its contents to stdout.
+
+    my $filename = "myfile.xz";
+    my $z = IO::Uncompress::UnLzip->new($filename)
+        or die "IO::Uncompress::UnLzip failed: $UnLzipError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -665,10 +682,6 @@ The default for this option is off.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -949,7 +962,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2022 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2023 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
