@@ -4,15 +4,15 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.204 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common 2.205 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base 2.204 ;
-use IO::Uncompress::Adapter::UnXz 2.204 ;
+use IO::Uncompress::Base 2.205 ;
+use IO::Uncompress::Adapter::UnXz 2.205 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnXzError);
 
-$VERSION = '2.204';
+$VERSION = '2.205';
 $UnXzError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
@@ -423,7 +423,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.xz> and write the
 uncompressed data to the file C<file1.txt>.
@@ -483,6 +483,9 @@ The format of the constructor for IO::Uncompress::UnXz is shown below
     my $z = IO::Uncompress::UnXz->new( $input [OPTS] )
         or die "IO::Uncompress::UnXz failed: $UnXzError\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::UnXz> object on success and undef on failure.
 The variable C<$UnXzError> will contain an error message on failure.
 
@@ -495,6 +498,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.xz> and write its contents to stdout.
+
+    my $filename = "myfile.xz";
+    my $z = IO::Uncompress::UnXz->new($filename)
+        or die "IO::Uncompress::UnXz failed: $UnXzError\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -624,10 +641,6 @@ Default is 0.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
